<?xml version='1.0' encoding='UTF-8'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0">
  <xsl:template name="genPath">
    <xsl:param name="prevPath"/>
    <xsl:variable name="currPath" select="concat('/',name(),'[', count(preceding-sibling::*[name() = name(current())])+1,']',$prevPath)"/>
    <xsl:for-each select="parent::*">
      <xsl:call-template name="genPath">
        <xsl:with-param name="prevPath" select="$currPath"/>
      </xsl:call-template>
    </xsl:for-each>
    <xsl:if test="not(parent::*)">
      <xsl:value-of select="$currPath"/>
    </xsl:if>
  </xsl:template>
  <xsl:strip-space elements="*"/>
  <xsl:template match="/">
    <warnings>
      <xsl:apply-templates select="//@*|node()"/>
    </warnings>
  </xsl:template>
  <xsl:template match="@*|text()"/>
  <xsl:template match="Package/@xsi:noNamespaceSchemaLocation[.='LIXI-CAL-2_6_13-Annotated.xsd']">
    <updated>
      <xsl:attribute name="name">xsi:noNamespaceSchemaLocation</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LIXI-CAL-2_6_13-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="update">LIXI-CAL-2_6_12-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/AccountVariation/@Type[.='Lending Guarantee Limit Decrease']">
    <removed>
      <xsl:attribute name="name">Type</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Lending Guarantee Limit Decrease</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/AccountVariation/@Type[.='Lending Guarantee Limit Increase']">
    <removed>
      <xsl:attribute name="name">Type</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Lending Guarantee Limit Increase</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/AccountVariation/LendingGuaranteeLimitDecrease">
    <removed>
      <xsl:attribute name="name">LendingGuaranteeLimitDecrease</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/AccountVariation/LendingGuaranteeLimitIncrease">
    <removed>
      <xsl:attribute name="name">LendingGuaranteeLimitIncrease</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/@CustomerTypeCode">
    <removed>
      <xsl:attribute name="name">CustomerTypeCode</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/@CustomerTypeDescription">
    <removed>
      <xsl:attribute name="name">CustomerTypeDescription</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Citywide Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Citywide Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Brighten Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Brighten Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/@InterestChargeFrequency">
    <removed>
      <xsl:attribute name="name">InterestChargeFrequency</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Citywide Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Citywide Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Brighten Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Brighten Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/OriginalTerm/@RolloverPeriodDuration">
    <removed>
      <xsl:attribute name="name">RolloverPeriodDuration</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/OriginalTerm/@RolloverPeriodUnits">
    <removed>
      <xsl:attribute name="name">RolloverPeriodUnits</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/RateComposition/@NetCustomerRiskMargin">
    <removed>
      <xsl:attribute name="name">NetCustomerRiskMargin</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/@InterestChargeFrequency">
    <removed>
      <xsl:attribute name="name">InterestChargeFrequency</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/Commission/@GSTAmount">
    <removed>
      <xsl:attribute name="name">GSTAmount</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/Commission/@ITCAmount">
    <removed>
      <xsl:attribute name="name">ITCAmount</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Citywide Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Citywide Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Brighten Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Brighten Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Citywide Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Citywide Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Brighten Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Brighten Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Brighten Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Citywide Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Citywide Home Loans']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Citywide Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Citywide Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@FinancialInstitution[.='Brighten Home Loans']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Brighten Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Brighten Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/RateComposition/@NetCustomerRiskMargin">
    <removed>
      <xsl:attribute name="name">NetCustomerRiskMargin</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/Term/@RolloverPeriodDuration">
    <removed>
      <xsl:attribute name="name">RolloverPeriodDuration</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/Term/@RolloverPeriodUnits">
    <removed>
      <xsl:attribute name="name">RolloverPeriodUnits</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Citywide Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Citywide Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Brighten Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Brighten Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/@CustomerTypeCode">
    <removed>
      <xsl:attribute name="name">CustomerTypeCode</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/@CustomerTypeDescription">
    <removed>
      <xsl:attribute name="name">CustomerTypeDescription</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/@FirstPropertyBuyer">
    <removed>
      <xsl:attribute name="name">FirstPropertyBuyer</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/@VisaSubclassCode">
    <removed>
      <xsl:attribute name="name">VisaSubclassCode</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Citywide Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Citywide Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Brighten Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Brighten Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/RealEstateAsset/EstimatedValue/@EstimateBasis[.='Bank Assessment']">
    <removed>
      <xsl:attribute name="name">EstimateBasis</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Bank Assessment</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/RealEstateAsset/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/RealEstateAsset/FundsDisbursement/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/@GSTAmount">
    <removed>
      <xsl:attribute name="name">GSTAmount</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/@ITCAmount">
    <removed>
      <xsl:attribute name="name">ITCAmount</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Citywide Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Citywide Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Brighten Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Brighten Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/PayableToAccount/@FinancialInstitution[.='Brighten Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/PayableToAccount/@FinancialInstitution[.='Citywide Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/@CustomerTypeCode">
    <removed>
      <xsl:attribute name="name">CustomerTypeCode</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/@CustomerTypeDescription">
    <removed>
      <xsl:attribute name="name">CustomerTypeDescription</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <removed>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Citywide Home Loans']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Citywide Home Loans</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Citywide Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Citywide Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@FinancialInstitution[.='Brighten Home Loans']">
    <updated>
      <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Brighten Home Loans</xsl:attribute>
      <xsl:attribute name="update">Other</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </updated>
    <xsl:choose>
      <xsl:when test="../@OtherFIName">
        <updated>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@OtherFIName">
            <xsl:attribute name="value">
              <xsl:value-of select="../@OtherFIName"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Brighten Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">OtherFIName</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Brighten Home Loans</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/NeedsAnalysis/Preferences/RepaymentTypeDetails/InterestOnly/Reason/@CreateFundsForInvestmentPurposes">
    <removed>
      <xsl:attribute name="name">CreateFundsForInvestmentPurposes</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/NeedsAnalysis/Preferences/RepaymentTypeDetails/InterestOnly/Reason/@MaximiseCashFlow">
    <removed>
      <xsl:attribute name="name">MaximiseCashFlow</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/NeedsAnalysis/Preferences/RepaymentTypeDetails/InterestOnly/Reason/@MinimiseCashFlowImpactDuringConstruction">
    <removed>
      <xsl:attribute name="name">MinimiseCashFlowImpactDuringConstruction</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/NeedsAnalysis/Preferences/RepaymentTypeDetails/InterestOnly/Reason/@MinimiseCashFlowImpactDuringTheBridgingPeriod">
    <removed>
      <xsl:attribute name="name">MinimiseCashFlowImpactDuringTheBridgingPeriod</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/NeedsAnalysis/Preferences/RepaymentTypeDetails/InterestOnly/Reason/@PlanToConvertToInvestmentProperty">
    <removed>
      <xsl:attribute name="name">PlanToConvertToInvestmentProperty</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/NeedsAnalysis/Preferences/RepaymentTypeDetails/InterestOnly/Reason/@PrincipalReductionsInAnOffsetFacility">
    <removed>
      <xsl:attribute name="name">PrincipalReductionsInAnOffsetFacility</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path"><xsl:call-template name="genPath"/></xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
      <xsl:attribute name="reason">attribute not available</xsl:attribute>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Instructions/ApplicationInstructions/Submit/Condition">
    <removed>
      <xsl:attribute name="name">Condition</xsl:attribute>
      <xsl:attribute name="type">element</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="reason">element not available</xsl:attribute>
      <xsl:copy-of select="."/>
    </removed>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/SchemaVersion/@LIXIVersion[.='2.6.13']">
    <updated>
      <xsl:attribute name="name">LIXIVersion</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">2.6.13</xsl:attribute>
      <xsl:attribute name="update">2.6.12</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
</xsl:stylesheet>
