<?xml version='1.0' encoding='UTF-8'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0">
  <xsl:template name="genPath">
    <xsl:param name="prevPath"/>
    <xsl:variable name="currPath" select="concat('/',name(),'[', count(preceding-sibling::*[name() = name(current())])+1,']',$prevPath)"/>
    <xsl:for-each select="parent::*">
      <xsl:call-template name="genPath">
        <xsl:with-param name="prevPath" select="$currPath"/>
      </xsl:call-template>
    </xsl:for-each>
    <xsl:if test="not(parent::*)">
      <xsl:value-of select="$currPath"/>
    </xsl:if>
  </xsl:template>
  <xsl:strip-space elements="*"/>
  <xsl:template match="/">
    <warnings>
      <xsl:apply-templates select="//@*|node()"/>
    </warnings>
  </xsl:template>
  <xsl:template match="@*|text()"/>
  <xsl:template match="Package/@xsi:noNamespaceSchemaLocation[.='LIXI-CNZ-2_0_1-Annotated.xsd']">
    <updated>
      <xsl:attribute name="name">xsi:noNamespaceSchemaLocation</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LIXI-CNZ-2_0_1-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="update">LIXI-CNZ-2_0_2-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='AMG']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMG</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='AMIST']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMIST</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='ANZ Wealth']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">ANZ Wealth</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='AV Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AV Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Aon Master Trust']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Aon Master Trust</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='AustSafe']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustSafe</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Australian Catholic']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Catholic</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Australian Ethical']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Ethical</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='AustralianSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustralianSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='BUSSQ']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">BUSSQ</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='CBUS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CBUS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='CareSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CareSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Catholic Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Catholic Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Christian Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Christian Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Club Plus Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Club Plus Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Colonial First State']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Colonial First State</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='CommBank Financial Planner']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CommBank Financial Planner</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='EISS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EISS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Energy Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Energy Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Equity Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Equity Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Essential Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Essential Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='First State Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First State Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='First Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='HESTA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">HESTA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='InTrust']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">InTrust</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Kinetic']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Kinetic</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='LUCRF']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LUCRF</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Legal Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Legal Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Local Government']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Local Government</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='MAP']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MAP</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='MTAA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MTAA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Media Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Media Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Mercer Wealth']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mercer Wealth</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Mine Wealth and Wellbeing']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mine Wealth and Wellbeing</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='NGS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NGS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='NSF Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NSF Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='OneAnswer']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">OneAnswer</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Plum']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Plum</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Prime']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Prime</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Russell Investments']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Russell Investments</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='SmartSave']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">SmartSave</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Statewide']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Statewide</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Sunsuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Sunsuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='TWUSUPER']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TWUSUPER</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='TasPlan']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TasPlan</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='VicSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">VicSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Virgin Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Virgin Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Visions']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Visions</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='AMG']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMG</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='AMIST']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMIST</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='ANZ Wealth']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">ANZ Wealth</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='AV Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AV Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Aon Master Trust']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Aon Master Trust</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='AustSafe']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustSafe</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Australian Catholic']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Catholic</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Australian Ethical']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Ethical</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='AustralianSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustralianSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='BUSSQ']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">BUSSQ</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='CBUS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CBUS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='CareSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CareSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Catholic Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Catholic Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Christian Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Christian Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Club Plus Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Club Plus Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Colonial First State']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Colonial First State</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='CommBank Financial Planner']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CommBank Financial Planner</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='EISS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EISS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Energy Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Energy Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Equity Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Equity Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Essential Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Essential Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='First State Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First State Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='First Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='HESTA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">HESTA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='InTrust']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">InTrust</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Kinetic']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Kinetic</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='LUCRF']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LUCRF</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Legal Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Legal Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Local Government']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Local Government</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='MAP']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MAP</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='MTAA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MTAA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Media Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Media Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Mercer Wealth']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mercer Wealth</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Mine Wealth and Wellbeing']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mine Wealth and Wellbeing</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='NGS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NGS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='NSF Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NSF Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='OneAnswer']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">OneAnswer</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Plum']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Plum</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Prime']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Prime</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Russell Investments']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Russell Investments</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='SmartSave']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">SmartSave</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Statewide']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Statewide</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Sunsuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Sunsuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='TWUSUPER']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TWUSUPER</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='TasPlan']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TasPlan</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='VicSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">VicSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Virgin Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Virgin Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Visions']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Visions</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='AMG']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMG</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='AMIST']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMIST</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='ANZ Wealth']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">ANZ Wealth</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='AV Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AV Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Aon Master Trust']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Aon Master Trust</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='AustSafe']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustSafe</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Australian Catholic']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Catholic</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Australian Ethical']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Ethical</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='AustralianSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustralianSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='BUSSQ']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">BUSSQ</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='CBUS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CBUS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='CareSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CareSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Catholic Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Catholic Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Christian Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Christian Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Club Plus Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Club Plus Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Colonial First State']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Colonial First State</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='CommBank Financial Planner']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CommBank Financial Planner</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='EISS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EISS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Energy Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Energy Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Equity Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Equity Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Essential Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Essential Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='First State Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First State Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='First Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='HESTA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">HESTA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='InTrust']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">InTrust</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Kinetic']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Kinetic</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='LUCRF']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LUCRF</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Legal Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Legal Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Local Government']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Local Government</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='MAP']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MAP</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='MTAA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MTAA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Media Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Media Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Mercer Wealth']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mercer Wealth</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Mine Wealth and Wellbeing']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mine Wealth and Wellbeing</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='NGS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NGS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='NSF Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NSF Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='OneAnswer']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">OneAnswer</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Plum']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Plum</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Prime']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Prime</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Russell Investments']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Russell Investments</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='SmartSave']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">SmartSave</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Statewide']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Statewide</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Sunsuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Sunsuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='TWUSUPER']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TWUSUPER</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='TasPlan']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TasPlan</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='VicSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">VicSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Virgin Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Virgin Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Visions']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Visions</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='AMG']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMG</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='AMIST']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMIST</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='ANZ Wealth']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">ANZ Wealth</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='AV Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AV Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Aon Master Trust']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Aon Master Trust</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='AustSafe']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustSafe</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Australian Catholic']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Catholic</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Australian Ethical']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Ethical</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='AustralianSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustralianSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='BUSSQ']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">BUSSQ</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='CBUS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CBUS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='CareSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CareSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Catholic Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Catholic Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Christian Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Christian Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Club Plus Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Club Plus Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Colonial First State']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Colonial First State</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='CommBank Financial Planner']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CommBank Financial Planner</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='EISS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EISS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Energy Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Energy Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Equity Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Equity Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Essential Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Essential Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='First State Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First State Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='First Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='HESTA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">HESTA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='InTrust']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">InTrust</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Kinetic']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Kinetic</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='LUCRF']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LUCRF</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Legal Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Legal Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Local Government']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Local Government</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='MAP']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MAP</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='MTAA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MTAA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Media Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Media Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Mercer Wealth']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mercer Wealth</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Mine Wealth and Wellbeing']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mine Wealth and Wellbeing</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='NGS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NGS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='NSF Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NSF Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='OneAnswer']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">OneAnswer</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Plum']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Plum</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Prime']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Prime</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Russell Investments']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Russell Investments</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='SmartSave']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">SmartSave</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Statewide']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Statewide</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Sunsuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Sunsuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='TWUSUPER']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TWUSUPER</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='TasPlan']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TasPlan</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='VicSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">VicSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Virgin Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Virgin Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Visions']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Visions</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='AMG']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMG</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='AMIST']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMIST</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='ANZ Wealth']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">ANZ Wealth</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='AV Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AV Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Aon Master Trust']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Aon Master Trust</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='AustSafe']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustSafe</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Australian Catholic']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Catholic</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Australian Ethical']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Ethical</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='AustralianSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustralianSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='BUSSQ']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">BUSSQ</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='CBUS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CBUS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='CareSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CareSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Catholic Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Catholic Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Christian Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Christian Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Club Plus Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Club Plus Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Colonial First State']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Colonial First State</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='CommBank Financial Planner']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CommBank Financial Planner</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='EISS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EISS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Energy Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Energy Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Equity Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Equity Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Essential Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Essential Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='First State Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First State Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='First Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='HESTA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">HESTA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='InTrust']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">InTrust</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Kinetic']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Kinetic</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='LUCRF']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LUCRF</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Legal Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Legal Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Local Government']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Local Government</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='MAP']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MAP</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='MTAA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MTAA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Media Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Media Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Mercer Wealth']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mercer Wealth</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Mine Wealth and Wellbeing']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mine Wealth and Wellbeing</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='NGS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NGS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='NSF Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NSF Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='OneAnswer']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">OneAnswer</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Plum']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Plum</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Prime']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Prime</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Russell Investments']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Russell Investments</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='SmartSave']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">SmartSave</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Statewide']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Statewide</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Sunsuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Sunsuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='TWUSUPER']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TWUSUPER</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='TasPlan']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TasPlan</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='VicSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">VicSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Virgin Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Virgin Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Visions']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Visions</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/@Description[.='Savings Account']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Savings Account</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Type">
        <updated>
          <xsl:attribute name="name">Type</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Type">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Type"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Savings Account</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Type</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Savings Account</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='AMG']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMG</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='AMIST']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMIST</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='ANZ Wealth']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">ANZ Wealth</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='AV Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AV Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Aon Master Trust']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Aon Master Trust</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='AustSafe']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustSafe</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Australian Catholic']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Catholic</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Australian Ethical']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Ethical</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='AustralianSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustralianSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='BUSSQ']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">BUSSQ</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='CBUS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CBUS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='CareSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CareSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Catholic Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Catholic Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Christian Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Christian Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Club Plus Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Club Plus Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Colonial First State']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Colonial First State</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='CommBank Financial Planner']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CommBank Financial Planner</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='EISS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EISS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Energy Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Energy Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Equity Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Equity Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Essential Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Essential Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='First State Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First State Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='First Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='HESTA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">HESTA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='InTrust']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">InTrust</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Kinetic']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Kinetic</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='LUCRF']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LUCRF</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Legal Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Legal Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Local Government']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Local Government</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='MAP']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MAP</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='MTAA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MTAA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Media Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Media Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Mercer Wealth']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mercer Wealth</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Mine Wealth and Wellbeing']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mine Wealth and Wellbeing</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='NGS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NGS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='NSF Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NSF Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='OneAnswer']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">OneAnswer</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Plum']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Plum</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Prime']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Prime</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Russell Investments']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Russell Investments</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='SmartSave']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">SmartSave</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Statewide']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Statewide</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Sunsuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Sunsuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='TWUSUPER']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TWUSUPER</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='TasPlan']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TasPlan</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='VicSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">VicSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Virgin Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Virgin Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Visions']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Visions</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='AMG']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMG</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='AMIST']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMIST</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='ANZ Wealth']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">ANZ Wealth</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='AV Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AV Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Aon Master Trust']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Aon Master Trust</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='AustSafe']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustSafe</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Australian Catholic']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Catholic</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Australian Ethical']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Ethical</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='AustralianSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustralianSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='BUSSQ']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">BUSSQ</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='CBUS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CBUS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='CareSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CareSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Catholic Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Catholic Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Christian Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Christian Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Club Plus Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Club Plus Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Colonial First State']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Colonial First State</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='CommBank Financial Planner']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CommBank Financial Planner</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='EISS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EISS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Energy Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Energy Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Equity Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Equity Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Essential Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Essential Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='First State Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First State Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='First Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='HESTA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">HESTA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='InTrust']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">InTrust</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Kinetic']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Kinetic</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='LUCRF']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LUCRF</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Legal Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Legal Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Local Government']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Local Government</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='MAP']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MAP</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='MTAA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MTAA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Media Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Media Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Mercer Wealth']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mercer Wealth</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Mine Wealth and Wellbeing']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mine Wealth and Wellbeing</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='NGS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NGS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='NSF Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NSF Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='OneAnswer']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">OneAnswer</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Plum']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Plum</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Prime']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Prime</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Russell Investments']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Russell Investments</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='SmartSave']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">SmartSave</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Statewide']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Statewide</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Sunsuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Sunsuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='TWUSUPER']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TWUSUPER</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='TasPlan']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TasPlan</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='VicSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">VicSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Virgin Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Virgin Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Visions']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Visions</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@OtherDescription[.='Australian Photo Firearms Licence']">
    <removed>
      <xsl:attribute name="name">OtherDescription</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Photo Firearms Licence</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@DocumentType">
        <updated>
          <xsl:attribute name="name">DocumentType</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@DocumentType">
            <xsl:attribute name="value">
              <xsl:value-of select="../@DocumentType"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Photo Firearms Licence</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">DocumentType</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Photo Firearms Licence</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@OtherDescription[.='Centrelink or Social Security Card']">
    <removed>
      <xsl:attribute name="name">OtherDescription</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Centrelink or Social Security Card</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@DocumentType">
        <updated>
          <xsl:attribute name="name">DocumentType</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@DocumentType">
            <xsl:attribute name="value">
              <xsl:value-of select="../@DocumentType"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Centrelink or Social Security Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">DocumentType</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Centrelink or Social Security Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@OtherDescription[.='Department of Veterans Affairs Card']">
    <removed>
      <xsl:attribute name="name">OtherDescription</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Department of Veterans Affairs Card</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@DocumentType">
        <updated>
          <xsl:attribute name="name">DocumentType</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@DocumentType">
            <xsl:attribute name="value">
              <xsl:value-of select="../@DocumentType"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Department of Veterans Affairs Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">DocumentType</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Department of Veterans Affairs Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@OtherDescription[.='Motor Vehicle Registration or Insurance Papers']">
    <removed>
      <xsl:attribute name="name">OtherDescription</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Motor Vehicle Registration or Insurance Papers</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@DocumentType">
        <updated>
          <xsl:attribute name="name">DocumentType</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@DocumentType">
            <xsl:attribute name="value">
              <xsl:value-of select="../@DocumentType"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Motor Vehicle Registration or Insurance Papers</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">DocumentType</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Motor Vehicle Registration or Insurance Papers</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@OtherDescription[.='Professional or Trade Association Card']">
    <removed>
      <xsl:attribute name="name">OtherDescription</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Professional or Trade Association Card</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@DocumentType">
        <updated>
          <xsl:attribute name="name">DocumentType</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@DocumentType">
            <xsl:attribute name="value">
              <xsl:value-of select="../@DocumentType"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Professional or Trade Association Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">DocumentType</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Professional or Trade Association Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@OtherDescription[.='Property Insurance Papers']">
    <removed>
      <xsl:attribute name="name">OtherDescription</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Property Insurance Papers</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@DocumentType">
        <updated>
          <xsl:attribute name="name">DocumentType</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@DocumentType">
            <xsl:attribute name="value">
              <xsl:value-of select="../@DocumentType"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Property Insurance Papers</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">DocumentType</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Property Insurance Papers</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@OtherDescription[.='Property Lease or Rental Agreement']">
    <removed>
      <xsl:attribute name="name">OtherDescription</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Property Lease or Rental Agreement</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@DocumentType">
        <updated>
          <xsl:attribute name="name">DocumentType</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@DocumentType">
            <xsl:attribute name="value">
              <xsl:value-of select="../@DocumentType"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Property Lease or Rental Agreement</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">DocumentType</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Property Lease or Rental Agreement</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@OtherDescription[.='State or Federal Government Employee Photo Identity Card']">
    <removed>
      <xsl:attribute name="name">OtherDescription</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">State or Federal Government Employee Photo Identity Card</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@DocumentType">
        <updated>
          <xsl:attribute name="name">DocumentType</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@DocumentType">
            <xsl:attribute name="value">
              <xsl:value-of select="../@DocumentType"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">State or Federal Government Employee Photo Identity Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">DocumentType</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">State or Federal Government Employee Photo Identity Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ProofOfIdentity/@OtherDescription[.='Tertiary Education Institution Photo Identity Card']">
    <removed>
      <xsl:attribute name="name">OtherDescription</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Tertiary Education Institution Photo Identity Card</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@DocumentType">
        <updated>
          <xsl:attribute name="name">DocumentType</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@DocumentType">
            <xsl:attribute name="value">
              <xsl:value-of select="../@DocumentType"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Tertiary Education Institution Photo Identity Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">DocumentType</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Tertiary Education Institution Photo Identity Card</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='AMG']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMG</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='AMIST']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMIST</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='ANZ Wealth']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">ANZ Wealth</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='AV Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AV Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Aon Master Trust']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Aon Master Trust</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='AustSafe']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustSafe</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Australian Catholic']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Catholic</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Australian Ethical']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Ethical</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='AustralianSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustralianSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='BUSSQ']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">BUSSQ</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='CBUS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CBUS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='CareSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CareSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Catholic Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Catholic Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Christian Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Christian Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Club Plus Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Club Plus Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Colonial First State']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Colonial First State</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='CommBank Financial Planner']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CommBank Financial Planner</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='EISS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EISS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Energy Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Energy Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Equity Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Equity Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Essential Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Essential Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='First State Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First State Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='First Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='HESTA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">HESTA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='InTrust']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">InTrust</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Kinetic']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Kinetic</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='LUCRF']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LUCRF</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Legal Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Legal Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Local Government']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Local Government</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='MAP']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MAP</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='MTAA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MTAA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Media Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Media Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Mercer Wealth']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mercer Wealth</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Mine Wealth and Wellbeing']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mine Wealth and Wellbeing</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='NGS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NGS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='NSF Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NSF Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='OneAnswer']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">OneAnswer</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Plum']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Plum</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Prime']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Prime</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Russell Investments']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Russell Investments</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='SmartSave']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">SmartSave</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Statewide']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Statewide</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Sunsuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Sunsuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='TWUSUPER']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TWUSUPER</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='TasPlan']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TasPlan</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='VicSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">VicSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Virgin Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Virgin Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Visions']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Visions</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='AMG']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMG</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMG</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='AMIST']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AMIST</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AMIST</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='ANZ Wealth']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">ANZ Wealth</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">ANZ Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='AV Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AV Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AV Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Aon Master Trust']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Aon Master Trust</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Aon Master Trust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='AustSafe']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustSafe</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustSafe</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Australian Catholic']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Catholic</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Catholic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Australian Ethical']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Australian Ethical</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Australian Ethical</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='AustralianSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">AustralianSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">AustralianSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='BUSSQ']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">BUSSQ</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">BUSSQ</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='CBUS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CBUS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CBUS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='CareSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CareSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CareSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Catholic Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Catholic Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Catholic Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Christian Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Christian Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Christian Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Club Plus Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Club Plus Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Club Plus Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Colonial First State']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Colonial First State</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Colonial First State</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='CommBank Financial Planner']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">CommBank Financial Planner</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">CommBank Financial Planner</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='EISS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">EISS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">EISS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Energy Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Energy Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Energy Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Equity Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Equity Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Equity Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Essential Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Essential Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Essential Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='First State Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First State Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First State Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='First Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">First Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">First Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='HESTA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">HESTA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">HESTA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='InTrust']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">InTrust</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">InTrust</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Kinetic']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Kinetic</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Kinetic</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='LUCRF']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LUCRF</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">LUCRF</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Legal Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Legal Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Legal Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Local Government']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Local Government</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Local Government</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='MAP']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MAP</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MAP</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='MTAA']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">MTAA</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">MTAA</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Media Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Media Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Media Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Mercer Wealth']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mercer Wealth</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mercer Wealth</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Mine Wealth and Wellbeing']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Mine Wealth and Wellbeing</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Mine Wealth and Wellbeing</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='NGS']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NGS</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NGS</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='NSF Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">NSF Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">NSF Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='OneAnswer']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">OneAnswer</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">OneAnswer</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Plum']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Plum</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Plum</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Prime']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Prime</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Prime</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Russell Investments']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Russell Investments</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Russell Investments</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='SmartSave']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">SmartSave</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">SmartSave</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Statewide']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Statewide</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Statewide</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Sunsuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Sunsuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Sunsuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='TWUSUPER']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TWUSUPER</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TWUSUPER</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='TasPlan']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TasPlan</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TasPlan</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='VicSuper']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">VicSuper</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">VicSuper</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Virgin Super']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Virgin Super</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Virgin Super</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Visions']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Visions</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Visions</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/SchemaVersion/@LIXIVersion[.='2.0.1']">
    <updated>
      <xsl:attribute name="name">LIXIVersion</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">2.0.1</xsl:attribute>
      <xsl:attribute name="update">2.0.2</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
</xsl:stylesheet>
